@@ -1,4 +1,7 @@
 # encoding: utf-8
+# python 3.x compatibility helpers
+from __future__ import unicode_literals
+
 import datetime
 from south.db import db
 from south.v2 import SchemaMigration
@@ -7,7 +10,7 @@ from django.db import models
 class Migration(SchemaMigration):
 
     def forwards(self, orm):
-        
+
         # Adding model 'Blog'
         db.create_table('planet_blog', (
             ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
@@ -120,7 +123,7 @@ class Migration(SchemaMigration):
 
 
     def backwards(self, orm):
-        
+
         # Removing unique constraint on 'Post', fields ['feed', 'guid']
         db.delete_unique('planet_post', ['feed_id', 'guid'])
 
